==> ui-1.8.1-sources.jar: nanorep/nanowidget/Components/NRArticleTitleView.java <==
package nanorep.nanowidget.Components;

import android.animation.Animator;
import android.animation.ObjectAnimator;
import android.content.Context;
import android.graphics.Color;
import android.graphics.Typeface;
import android.text.Layout;
import android.text.StaticLayout;
import android.view.InflateException;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.ImageButton;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.nanorep.nanoclient.Response.NRConfiguration;

import nanorep.nanowidget.Components.AbstractViews.NRCustomTitleView;
import nanorep.nanowidget.R;
import nanorep.nanowidget.SearchViewsProvider;

/**
 * Created by nanorep on 29/09/2016.
 */

public class NRArticleTitleView extends NRCustomTitleView{

    private TextView mTitleView;
    private ImageButton mUnFoldButton;
    private ImageButton mShareButton;
    private LinearLayout titleLayout;
    private Context context;

    private String textColorAnswer = "#0aa0ff";
    private String textColorFaq = "#4a4a4a";

    private String textFontAnswer = "sans-serif-medium";
    private String textFontFaq = "sans-serif-light";


    private boolean closed = true;

    public NRArticleTitleView(Context context, SearchViewsProvider viewsProvider) {
        super(context);
        this.context = context;

        try {
            LayoutInflater.from(context).inflate(viewsProvider.getArticleTitleLayout(), this);
        } catch (NullPointerException | InflateException e) {
            LayoutInflater.from(context).inflate(R.layout.article_title, this);
        }
    }

    @Override
    public void onViewAdded(View child) {
        super.onViewAdded(child);

        titleLayout = child.findViewById(R.id.titleLayout);

        mTitleView = child.findViewById(R.id.titleTextView);

        mUnFoldButton = child.findViewById(R.id.unFoldButton);
        mUnFoldButton.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                mListener.onTitleClicked();
            }
        });



        mShareButton = child.findViewById(R.id.shareButton);
        mShareButton.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                mListener.onShareClicked();
            }
        });
    }

    private void setUnfoldButtonImage() {
        if(mUnFoldButton != null) {
//            if (mUnFoldButton.getRotation() == -270 && closed || mUnFoldButton.getRotation() == -90 && !closed)  {
//                ObjectAnimator.ofFloat(mUnFoldButton, "rotation", 0, !closed ? -270 : -90).start();
//            }
            if(!closed) {
                mUnFoldButton.setVisibility(View.INVISIBLE);
            } else {
                mUnFoldButton.setVisibility(View.VISIBLE);
            }

        }
    }

    @Override
    public void setTitleText(final String text) {
        mTitleView.setText(text);

        mTitleView.setMaxLines(2);
    }

    @Override
    public void unfold(boolean closed) {
        this.closed = !closed;

        setTitleColor();
        setTitleFont();
        setUnfoldButtonImage();
        setShareImage();

        if(!this.closed) {
            collapseTextView(100, 1000);
            mListener.onTitleCollapsed(getCollapsedHeight(mTitleView.getText()));
        } else {
            collapseTextView(2, 100);
        }
    }

    private void setTitleFont() {
        String font = textFontFaq;

        if(!closed) {
            font = textFontAnswer;
        }

        mTitleView.setTypeface(Typeface.create(font, Typeface.NORMAL));
    }

    private void setShareImage() {
        if(closed) { // answer is closed, max 2 lines
            mShareButton.setVisibility(View.GONE);
        } else
        {
//            mShareButton.setVisibility(View.VISIBLE);
        }
    }


    private void setTitleColor() {

        String color = textColorFaq;

        if(!closed) {
            color = textColorAnswer;
        }

        if(!color.startsWith("#")) {
            color = "#" + color;
        }

        mTitleView.setTextColor(Color.parseColor(color));
    }

    @Override
    public int getTitleHeight(String text) {

        return titleLayout.getHeight();
    }

    @Override
    public void resetView() {
//        LinearLayout.LayoutParams params = (LinearLayout.LayoutParams)titleLayout.getLayoutParams();
//        params.leftMargin = 0;
//        params.rightMargin = 0;
//        titleLayout.setLayoutParams(params);
    }

    private void collapseTextView(final int lines, long duration){
        ObjectAnimator animation = ObjectAnimator.ofInt(mTitleView, "maxLines", lines);
        animation.setDuration(duration).start();

        animation.addListener(new Animator.AnimatorListener() {
            @Override
            public void onAnimationStart(Animator animation) {

            }

            @Override
            public void onAnimationEnd(Animator animation) {
                if(closed) {
                    mListener.onTitleCollapsed(mTitleView.getHeight());
                }
            }

            @Override
            public void onAnimationCancel(Animator animation) {

            }

            @Override
            public void onAnimationRepeat(Animator animation) {

            }
        });
    }

    public int getCollapsedHeight(CharSequence text) {

        int mMeasuredHeight = (new StaticLayout(text, mTitleView.getPaint(), mTitleView.getWidth(), Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, true)).getHeight();

        if(mMeasuredHeight < mTitleView.getHeight()) {
            mMeasuredHeight = mTitleView.getHeight();
        }
        return mMeasuredHeight;
    }

    public void configViewObjects(NRConfiguration nrConfiguration) {
        NRConfiguration.NRContent content = nrConfiguration.getContent();

        // text color
        if(content.getAnswerTitleColor() != null && !"".equals(content.getAnswerTitleColor())) {
            textColorAnswer = content.getAnswerTitleColor();
        }

        // title font
        if(content.getAnswerTextFont() != null && !"".equals(content.getAnswerTextFont())) {
            textFontAnswer = content.getAnswerTitleFont();
        }
    }

    @Override
    public void setTitleMaxLines(int lines) {
        mTitleView.setMaxLines(lines);
    }
}

==> ui-2.1.1-sources.jar: nanorep/nanowidget/Components/NRArticleTitleView.java <==
package nanorep.nanowidget.Components;

import android.animation.Animator;
import android.animation.ObjectAnimator;
import android.content.Context;
import android.graphics.Color;
import android.graphics.Typeface;
import android.support.annotation.NonNull;
import android.text.Layout;
import android.text.StaticLayout;
import android.util.Log;
import android.view.InflateException;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.ImageButton;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.nanorep.nanoclient.Response.NRConfiguration;

import nanorep.nanowidget.Components.AbstractViews.NRCustomTitleView;
import nanorep.nanowidget.R;
import nanorep.nanowidget.SearchViewsProvider;

/**
 * Created by nanorep on 29/09/2016.
 */

public class NRArticleTitleView extends NRCustomTitleView{

    private TextView mTitleView;
    private ImageButton mUnFoldButton;
    private ImageButton mShareButton;
    private LinearLayout titleLayout;
    private Context context;

    private String textColorAnswer = "#0aa0ff";
    private String textColorFaq = "#4a4a4a";

    private String textFontAnswer = "sans-serif-medium";
    private String textFontFaq = "sans-serif-light";


    private boolean closed = true;

    public NRArticleTitleView(Context context, @NonNull SearchViewsProvider viewsProvider) {
        super(context);
        this.context = context;

        try {
            LayoutInflater.from(context).inflate(viewsProvider.getArticleTitleLayout(), this);
        } catch (InflateException e) {
            Log.d("InflateError", "Custom Layout failed to be inflated");
            LayoutInflater.from(context).inflate(R.layout.article_title, this);
        }
    }

    @Override
    public void onViewAdded(View child) {
        super.onViewAdded(child);

        titleLayout = child.findViewById(R.id.titleLayout);

        mTitleView = child.findViewById(R.id.titleTextView);

        mUnFoldButton = child.findViewById(R.id.unFoldButton);
        mUnFoldButton.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                mListener.onTitleClicked();
            }
        });



        mShareButton = child.findViewById(R.id.shareButton);
        mShareButton.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                mListener.onShareClicked();
            }
        });
    }

    private void setUnfoldButtonImage() {
        if(mUnFoldButton != null) {
//            if (mUnFoldButton.getRotation() == -270 && closed || mUnFoldButton.getRotation() == -90 && !closed)  {
//                ObjectAnimator.ofFloat(mUnFoldButton, "rotation", 0, !closed ? -270 : -90).start();
//            }
            if(!closed) {
                mUnFoldButton.setVisibility(View.INVISIBLE);
            } else {
                mUnFoldButton.setVisibility(View.VISIBLE);
            }

        }
    }

    @Override
    public void setTitleText(final String text) {
        mTitleView.setText(text);

        mTitleView.setMaxLines(2);
    }

    @Override
    public void unfold(boolean closed) {
        this.closed = !closed;

        setTitleColor();
        setTitleFont();
        setUnfoldButtonImage();
        setShareImage();

        if(!this.closed) {
            collapseTextView(100, 1000);
            mListener.onTitleCollapsed(getCollapsedHeight(mTitleView.getText()));
        } else {
            collapseTextView(2, 100);
        }
    }

    private void setTitleFont() {
        String font = textFontFaq;

        if(!closed) {
            font = textFontAnswer;
        }

        mTitleView.setTypeface(Typeface.create(font, Typeface.NORMAL));
    }

    private void setShareImage() {
        if(closed) { // answer is closed, max 2 lines
            mShareButton.setVisibility(View.GONE);
        } else
        {
//            mShareButton.setVisibility(View.VISIBLE);
        }
    }


    private void setTitleColor() {

        String color = textColorFaq;

        if(!closed) {
            color = textColorAnswer;
        }

        if(!color.startsWith("#")) {
            color = "#" + color;
        }

        mTitleView.setTextColor(Color.parseColor(color));
    }

    @Override
    public int getTitleHeight(String text) {

        return titleLayout.getHeight();
    }

    @Override
    public void resetView() {
//        LinearLayout.LayoutParams params = (LinearLayout.LayoutParams)titleLayout.getLayoutParams();
//        params.leftMargin = 0;
//        params.rightMargin = 0;
//        titleLayout.setLayoutParams(params);
    }

    private void collapseTextView(final int lines, long duration){
        ObjectAnimator animation = ObjectAnimator.ofInt(mTitleView, "maxLines", lines);
        animation.setDuration(duration).start();

        animation.addListener(new Animator.AnimatorListener() {
            @Override
            public void onAnimationStart(Animator animation) {

            }

            @Override
            public void onAnimationEnd(Animator animation) {
                if(closed) {
                    mListener.onTitleCollapsed(mTitleView.getHeight());
                }
            }

            @Override
            public void onAnimationCancel(Animator animation) {

            }

            @Override
            public void onAnimationRepeat(Animator animation) {

            }
        });
    }

    public int getCollapsedHeight(CharSequence text) {

        int mMeasuredHeight = (new StaticLayout(text, mTitleView.getPaint(), mTitleView.getWidth(), Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, true)).getHeight();

        if(mMeasuredHeight < mTitleView.getHeight()) {
            mMeasuredHeight = mTitleView.getHeight();
        }
        return mMeasuredHeight;
    }

    public void configViewObjects(NRConfiguration nrConfiguration) {
        NRConfiguration.NRContent content = nrConfiguration.getContent();

        // text color
        if(content.getAnswerTitleColor() != null && !"".equals(content.getAnswerTitleColor())) {
            textColorAnswer = content.getAnswerTitleColor();
        }

        // title font
        if(content.getAnswerTextFont() != null && !"".equals(content.getAnswerTextFont())) {
            textFontAnswer = content.getAnswerTitleFont();
        }
    }

    @Override
    public void setTitleMaxLines(int lines) {
        mTitleView.setMaxLines(lines);
    }
}
